--[[***********************************************************************
    SLTimex: Options.lua
    Author: Taffu of Draka
    Version: 2.0 r11
    Website: http://www.wowinterface.com/portal.php?&uid=24019
    Revision Date: November 22, 2007
    
    SLTimex is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    SLTimex is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SLTimex.  If not, see <http://www.gnu.org/licenses/>.
*************************************************************************]]

local L = AceLibrary("AceLocale-2.2"):new("SLT")
local SML = AceLibrary("SharedMedia-1.0")

local postable = {
    ["LEFT"] = L["Left"],
    ["TOPLEFT"] = L["TopLeft"],
    ["TOP"] = L["Top"],
    ["TOPRIGHT"] = L["TopRight"],
    ["RIGHT"] = L["Right"],
    ["BOTTOMRIGHT"] = L["BottomRight"],
    ["BOTTOM"] = L["Bottom"],
    ["BOTTOMLEFT"] = L["BottomLeft"],
    ["CENTER"] = L["Center"],
}

local justifytable = {
    ["LEFT"] = L["Left"],
    ["CENTER"] = L["Center"],
    ["RIGHT"] = L["Right"],
}

local frametable = {
    ["UIParent"] = L["UIParent"],
    ["Clock"] = L["Clock"],
    ["SClock"] = L["Server Clock"],
    ["FPS"] = L["FPS"],
    ["Mem"] = L["Memory"],
    ["Lag"] = L["Latency"],
}

SLT_Options = {
    type = "group",
    args = {
        general = {
            type = "group",
            name = L["General"],
            desc = L["General Options"],
            order = 100,
            args = {
                isLocked = {
                    type = "toggle",
                    name = L["Locked"],
                    desc = L["Locked Desc"],
                    get = function() return SLT.db.profile.isLocked end,
                    set = function() SLT.db.profile.isLocked = not SLT.db.profile.isLocked SLT:LoadSettings() end,
                    order = 20,
                },
                isClamped = {
                    type = "toggle",
                    name = L["Clamp to Screen"],
                    desc = L["Clamp to Screen Desc"],
                    get = function() return SLT.db.profile.isClamped end,
                    set = function() SLT.db.profile.isClamped = not SLT.db.profile.isClamped SLT:LoadSettings() end,
                    order = 30,
                },
                updateDelay = {
                    type = "range",
                    name = L["Update Delay"],
                    desc = L["Update Delay Desc"],
                    min = 1,
                    max = 60,
                    step = 1,
                    get = function() return SLT.db.profile.updateDelay end,
                    set = function(v) SLT.db.profile.updateDelay = v SLT:LoadSettings() end,
                    order = 40,
                },
            },
        },
        clock = {
            type = "group",
            name = L["Clock"],
            desc = L["Clock Options"],
            order = 200,
            args = {
                enable = {
                    type = "toggle",
                    name = L["Hidden"],
                    desc = L["Hidden Desc"],
                    get = function() return SLT.db.profile.Clock.hidden end,
                    set = function() SLT.db.profile.Clock.hidden = not SLT.db.profile.Clock.hidden SLT:LoadSettings() end,
                    order = 10,
                },
                is24Hour = {
                    type = "toggle",
                    name = L["24 Hour"],
                    desc = L["24 Hour Desc"],
                    get = function() return SLT.db.profile.Clock.is24Hour end,
                    set = function() SLT.db.profile.Clock.is24Hour = not SLT.db.profile.Clock.is24Hour SLT:LoadSettings() end,
                    order = 20,
                },
                fontFace = {
                    type = "text",
                    name = L["Font Face"],
                    desc = L["Font Face Desc"],
                    validate = SML:List("font"),
                    get = function() return SLT.db.profile.Clock.fontFace end,
                    set = function(v) SLT.db.profile.Clock.fontFace = v SLT:LoadSettings() end,
                    order = 100,
                },
                fontSize = {
                    type = "range",
                    name = L["Font Size"],
                    desc = L["Font Size Desc"],
                    min = 8,
                    max = 38,
                    step = 1,
                    get = function() return SLT.db.profile.Clock.fontSize end,
                    set = function(v) SLT.db.profile.Clock.fontSize = v SLT:LoadSettings() end,
                    order = 200,
                },
                justify = {
                    type = "text",
                    name = L["Justify"],
                    desc = L["Justify Desc"],
                    validate = justifytable,
                    get = function() return SLT.db.profile.Clock.justify end,
                    set = function(v) SLT.db.profile.Clock.justify = v SLT:LoadSettings() end,
                    order = 210,
                },
                clockSep = {
                    type = "text",
                    name = L["Clock Seperator"],
                    desc = L["Clock Seperator Desc"],
                    usage = L["<Character>"],
                    get = function() return SLT.db.profile.Clock.seperator end,
                    set = function(v) SLT.db.profile.Clock.seperator = v SLT:LoadSettings() end,
                    order = 220,
                },
                anchor = {
                    type = "text",
                    name = L["Anchor"],
                    desc = L["Anchor Desc"],
                    validate = frametable,
                    get = function() return SLT.db.profile.Clock.point.a end,
                    set = function(v) 
                        SLT.db.profile.Clock.point.a = v
                        SLT.db.profile.Clock.point.x = 0
                        SLT.db.profile.Clock.point.y = 0
                        SLT:LoadSettings() 
                    end,
                    order = 300,
                },
                anchorTo = {
                    type = "text",
                    name = L["Anchor To"],
                    desc = L["Anchor To Desc"],
                    validate = postable,
                    get = function() return SLT.db.profile.Clock.point.aT end,
                    set = function(v) 
                        SLT.db.profile.Clock.point.aT = v
                        SLT.db.profile.Clock.point.x = 0
                        SLT.db.profile.Clock.point.y = 0
                        SLT:LoadSettings()
                    end,
                    order = 400,
                },
                offX = {
                    type = "range",
                    name = L["X Offset"],
                    desc = L["X Offset Desc"],
                    min = -1200,
                    max = 1200,
                    step = 1,
                    get = function() return SLT.db.profile.Clock.point.x end,
                    set = function(v) SLT.db.profile.Clock.point.x = v SLT:LoadSettings() end,
                    order = 500,
                },
                offY = {
                    type = "range",
                    name = L["Y Offset"],
                    desc = L["Y Offset Desc"],
                    min = -1000,
                    max = 1000,
                    step = 1,
                    get = function() return SLT.db.profile.Clock.point.y end,
                    set = function(v) SLT.db.profile.Clock.point.y = v SLT:LoadSettings() end,
                    order = 600,
                },
            },
        },
        sclock = {
            type = "group",
            name = L["Server Clock"],
            desc = L["Server Clock Options"],
            order = 300,
            args = {
                enable = {
                    type = "toggle",
                    name = L["Hidden"],
                    desc = L["Hidden Desc"],
                    get = function() return SLT.db.profile.SClock.hidden end,
                    set = function() SLT.db.profile.SClock.hidden = not SLT.db.profile.SClock.hidden SLT:LoadSettings() end,
                    order = 10,
                },
                is24Hour = {
                    type = "toggle",
                    name = L["24 Hour"],
                    desc = L["24 Hour Desc"],
                    get = function() return SLT.db.profile.SClock.is24Hour end,
                    set = function() SLT.db.profile.SClock.is24Hour = not SLT.db.profile.SClock.is24Hour SLT:LoadSettings() end,
                    order = 20,
                },
                fontFace = {
                    type = "text",
                    name = L["Font Face"],
                    desc = L["Font Face Desc"],
                    validate = SML:List("font"),
                    get = function() return SLT.db.profile.SClock.fontFace end,
                    set = function(v) SLT.db.profile.SClock.fontFace = v SLT:LoadSettings() end,
                    order = 100,
                },
                fontSize = {
                    type = "range",
                    name = L["Font Size"],
                    desc = L["Font Size Desc"],
                    min = 8,
                    max = 38,
                    step = 1,
                    get = function() return SLT.db.profile.SClock.fontSize end,
                    set = function(v) SLT.db.profile.SClock.fontSize = v SLT:LoadSettings() end,
                    order = 200,
                },
                justify = {
                    type = "text",
                    name = L["Justify"],
                    desc = L["Justify Desc"],
                    validate = justifytable,
                    get = function() return SLT.db.profile.SClock.justify end,
                    set = function(v) SLT.db.profile.SClock.justify = v SLT:LoadSettings() end,
                    order = 210,
                },
                clockSep = {
                    type = "text",
                    name = L["Clock Seperator"],
                    desc = L["Clock Seperator Desc"],
                    usage = L["<Character>"],
                    get = function() return SLT.db.profile.SClock.seperator end,
                    set = function(v) SLT.db.profile.SClock.seperator = v SLT:LoadSettings() end,
                    order = 220,
                },
                anchor = {
                    type = "text",
                    name = L["Anchor"],
                    desc = L["Anchor Desc"],
                    validate = frametable,
                    get = function() return SLT.db.profile.SClock.point.a end,
                    set = function(v) 
                        SLT.db.profile.SClock.point.a = v
                        SLT.db.profile.SClock.point.x = 0
                        SLT.db.profile.SClock.point.y = 0
                        SLT:LoadSettings() 
                    end,
                    order = 300,
                },
                anchorTo = {
                    type = "text",
                    name = L["Anchor To"],
                    desc = L["Anchor To Desc"],
                    validate = postable,
                    get = function() return SLT.db.profile.SClock.point.aT end,
                    set = function(v) 
                        SLT.db.profile.SClock.point.aT = v
                        SLT.db.profile.SClock.point.x = 0
                        SLT.db.profile.SClock.point.y = 0
                        SLT:LoadSettings()
                    end,
                    order = 400,
                },
                offX = {
                    type = "range",
                    name = L["X Offset"],
                    desc = L["X Offset Desc"],
                    min = -1200,
                    max = 1200,
                    step = 1,
                    get = function() return SLT.db.profile.SClock.point.x end,
                    set = function(v) SLT.db.profile.SClock.point.x = v SLT:LoadSettings() end,
                    order = 500,
                },
                offY = {
                    type = "range",
                    name = L["Y Offset"],
                    desc = L["Y Offset Desc"],
                    min = -1000,
                    max = 1000,
                    step = 1,
                    get = function() return SLT.db.profile.SClock.point.y end,
                    set = function(v) SLT.db.profile.SClock.point.y = v SLT:LoadSettings() end,
                    order = 600,
                },
            },
        },
        fps = {
            type = "group",
            name = L["FPS"],
            desc = L["FPS Options"],
            order = 400,
            args = {
                enable = {
                    type = "toggle",
                    name = L["Hidden"],
                    desc = L["Hidden Desc"],
                    get = function() return SLT.db.profile.FPS.hidden end,
                    set = function() SLT.db.profile.FPS.hidden = not SLT.db.profile.FPS.hidden SLT:LoadSettings() end,
                    order = 10,
                },
                fontFace = {
                    type = "text",
                    name = L["Font Face"],
                    desc = L["Font Face Desc"],
                    validate = SML:List("font"),
                    get = function() return SLT.db.profile.FPS.fontFace end,
                    set = function(v) SLT.db.profile.FPS.fontFace = v SLT:LoadSettings() end,
                    order = 100,
                },
                fontSize = {
                    type = "range",
                    name = L["Font Size"],
                    desc = L["Font Size Desc"],
                    min = 8,
                    max = 38,
                    step = 1,
                    get = function() return SLT.db.profile.FPS.fontSize end,
                    set = function(v) SLT.db.profile.FPS.fontSize = v SLT:LoadSettings() end,
                    order = 200,
                },
                justify = {
                    type = "text",
                    name = L["Justify"],
                    desc = L["Justify Desc"],
                    validate = justifytable,
                    get = function() return SLT.db.profile.FPS.justify end,
                    set = function(v) SLT.db.profile.FPS.justify = v SLT:LoadSettings() end,
                    order = 210,
                },
                anchor = {
                    type = "text",
                    name = L["Anchor"],
                    desc = L["Anchor Desc"],
                    validate = frametable,
                    get = function() return SLT.db.profile.FPS.point.a end,
                    set = function(v) 
                        SLT.db.profile.FPS.point.a = v
                        SLT.db.profile.FPS.point.x = 0
                        SLT.db.profile.FPS.point.y = 0
                        SLT:LoadSettings() 
                    end,
                    order = 300,
                },
                anchorTo = {
                    type = "text",
                    name = L["Anchor To"],
                    desc = L["Anchor To Desc"],
                    validate = postable,
                    get = function() return SLT.db.profile.FPS.point.aT end,
                    set = function(v) 
                        SLT.db.profile.FPS.point.aT = v
                        SLT.db.profile.FPS.point.x = 0
                        SLT.db.profile.FPS.point.y = 0
                        SLT:LoadSettings()
                    end,
                    order = 400,
                },
                offX = {
                    type = "range",
                    name = L["X Offset"],
                    desc = L["X Offset Desc"],
                    min = -1200,
                    max = 1200,
                    step = 1,
                    get = function() return SLT.db.profile.FPS.point.x end,
                    set = function(v) SLT.db.profile.FPS.point.x = v SLT:LoadSettings() end,
                    order = 500,
                },
                offY = {
                    type = "range",
                    name = L["Y Offset"],
                    desc = L["Y Offset Desc"],
                    min = -1000,
                    max = 1000,
                    step = 1,
                    get = function() return SLT.db.profile.FPS.point.y end,
                    set = function(v) SLT.db.profile.FPS.point.y = v SLT:LoadSettings() end,
                    order = 600,
                },
            },
        },
        mem = {
            type = "group",
            name = L["Memory"],
            desc = L["Memory Options"],
            order = 500,
            args = {
                enable = {
                    type = "toggle",
                    name = L["Hidden"],
                    desc = L["Hidden Desc"],
                    get = function() return SLT.db.profile.Mem.hidden end,
                    set = function() SLT.db.profile.Mem.hidden = not SLT.db.profile.Mem.hidden SLT:LoadSettings() end,
                    order = 10,
                },
                fontFace = {
                    type = "text",
                    name = L["Font Face"],
                    desc = L["Font Face Desc"],
                    validate = SML:List("font"),
                    get = function() return SLT.db.profile.Mem.fontFace end,
                    set = function(v) SLT.db.profile.Mem.fontFace = v SLT:LoadSettings() end,
                    order = 100,
                },
                fontSize = {
                    type = "range",
                    name = L["Font Size"],
                    desc = L["Font Size Desc"],
                    min = 8,
                    max = 38,
                    step = 1,
                    get = function() return SLT.db.profile.Mem.fontSize end,
                    set = function(v) SLT.db.profile.Mem.fontSize = v SLT:LoadSettings() end,
                    order = 200,
                },
                justify = {
                    type = "text",
                    name = L["Justify"],
                    desc = L["Justify Desc"],
                    validate = justifytable,
                    get = function() return SLT.db.profile.Mem.justify end,
                    set = function(v) SLT.db.profile.Mem.justify = v SLT:LoadSettings() end,
                    order = 210,
                },
                anchor = {
                    type = "text",
                    name = L["Anchor"],
                    desc = L["Anchor Desc"],
                    validate = frametable,
                    get = function() return SLT.db.profile.Mem.point.a end,
                    set = function(v) 
                        SLT.db.profile.Mem.point.a = v
                        SLT.db.profile.Mem.point.x = 0
                        SLT.db.profile.Mem.point.y = 0
                        SLT:LoadSettings() 
                    end,
                    order = 300,
                },
                anchorTo = {
                    type = "text",
                    name = L["Anchor To"],
                    desc = L["Anchor To Desc"],
                    validate = postable,
                    get = function() return SLT.db.profile.Mem.point.aT end,
                    set = function(v) 
                        SLT.db.profile.Mem.point.aT = v
                        SLT.db.profile.Mem.point.x = 0
                        SLT.db.profile.Mem.point.y = 0
                        SLT:LoadSettings()
                    end,
                    order = 400,
                },
                offX = {
                    type = "range",
                    name = L["X Offset"],
                    desc = L["X Offset Desc"],
                    min = -1200,
                    max = 1200,
                    step = 1,
                    get = function() return SLT.db.profile.Mem.point.x end,
                    set = function(v) SLT.db.profile.Mem.point.x = v SLT:LoadSettings() end,
                    order = 500,
                },
                offY = {
                    type = "range",
                    name = L["Y Offset"],
                    desc = L["Y Offset Desc"],
                    min = -1000,
                    max = 1000,
                    step = 1,
                    get = function() return SLT.db.profile.Mem.point.y end,
                    set = function(v) SLT.db.profile.Mem.point.y = v SLT:LoadSettings() end,
                    order = 600,
                },
            },
        },
        lag = {
            type = "group",
            name = L["Latency"],
            desc = L["Latency Options"],
            order = 600,
            args = {
                enable = {
                    type = "toggle",
                    name = L["Hidden"],
                    desc = L["Hidden Desc"],
                    get = function() return SLT.db.profile.Lag.hidden end,
                    set = function() SLT.db.profile.Lag.hidden = not SLT.db.profile.Lag.hidden SLT:LoadSettings() end,
                    order = 10,
                },
                fontFace = {
                    type = "text",
                    name = L["Font Face"],
                    desc = L["Font Face Desc"],
                    validate = SML:List("font"),
                    get = function() return SLT.db.profile.Lag.fontFace end,
                    set = function(v) SLT.db.profile.Lag.fontFace = v SLT:LoadSettings() end,
                    order = 100,
                },
                fontSize = {
                    type = "range",
                    name = L["Font Size"],
                    desc = L["Font Size Desc"],
                    min = 8,
                    max = 38,
                    step = 1,
                    get = function() return SLT.db.profile.Lag.fontSize end,
                    set = function(v) SLT.db.profile.Lag.fontSize = v SLT:LoadSettings() end,
                    order = 200,
                },
                justify = {
                    type = "text",
                    name = L["Justify"],
                    desc = L["Justify Desc"],
                    validate = justifytable,
                    get = function() return SLT.db.profile.Lag.justify end,
                    set = function(v) SLT.db.profile.Lag.justify = v SLT:LoadSettings() end,
                    order = 210,
                },
                anchor = {
                    type = "text",
                    name = L["Anchor"],
                    desc = L["Anchor Desc"],
                    validate = frametable,
                    get = function() return SLT.db.profile.Lag.point.a end,
                    set = function(v) 
                        SLT.db.profile.Lag.point.a = v
                        SLT.db.profile.Lag.point.x = 0
                        SLT.db.profile.Lag.point.y = 0
                        SLT:LoadSettings() 
                    end,
                    order = 300,
                },
                anchorTo = {
                    type = "text",
                    name = L["Anchor To"],
                    desc = L["Anchor To Desc"],
                    validate = postable,
                    get = function() return SLT.db.profile.Lag.point.aT end,
                    set = function(v) 
                        SLT.db.profile.Lag.point.aT = v
                        SLT.db.profile.Lag.point.x = 0
                        SLT.db.profile.Lag.point.y = 0
                        SLT:LoadSettings()
                    end,
                    order = 400,
                },
                offX = {
                    type = "range",
                    name = L["X Offset"],
                    desc = L["X Offset Desc"],
                    min = -1200,
                    max = 1200,
                    step = 1,
                    get = function() return SLT.db.profile.Lag.point.x end,
                    set = function(v) SLT.db.profile.Lag.point.x = v SLT:LoadSettings() end,
                    order = 500,
                },
                offY = {
                    type = "range",
                    name = L["Y Offset"],
                    desc = L["Y Offset Desc"],
                    min = -1000,
                    max = 1000,
                    step = 1,
                    get = function() return SLT.db.profile.Lag.point.y end,
                    set = function(v) SLT.db.profile.Lag.point.y = v SLT:LoadSettings() end,
                    order = 600,
                },
            },
        },
    },
}